==> core_models-0.0.1.gem: app/models/core_models/base/address.rb <==
require 'geocoder'

module CoreModels
  class Base::Address < ActiveRecord::Base
    belongs_to :country, :class_name => '::CoreModels::Base::Country'
    belongs_to :owner, :polymorphic => true

    #::Gmaps4rails::ActsAsGmappable::ClassMethods.acts_as_gmappable :validation => false
    #acts_as_gmappable :validation => false unless Rails.env == 'test'
    geocoded_by         :gmaps4rails_address                # can also be an IP address
    reverse_geocoded_by :latitude, :longitude
    after_validation    :geocode unless Rails.env == 'test' # auto-fetch coordinates

    attr_accessible :room, :building, :address_line_1, :address_line_2, :postal_code, :town, :city, :region
    attr_accessible :email_1, :email_2, :email_3, :url_1, :url_2, :url_3
    attr_accessible :telephone_number_1, :telephone_number_2, :fax_number_1, :fax_number_2

    #if ::Rails.env.test?
    attr_accessible :country, :country_id
    attr_accessible :owner, :owner_id
    #end

    attr_accessible :world_coordinates

    validates :address_line_1, :presence => true
    #validates :postal_code, :presence => true
    #validates :town, :presence => true
    #validates :region, :presence => true
    validates :country, :presence => true

    #----------------------------------------------------------------------------

    def to_s
      summary
    end

    def summary
      summary_en
    end

    def summary_en
      output = self.building.blank? ? '' : self.building
      output += self.building.blank? ? self.address_line_1 : ', ' + self.address_line_1
      output += ', ' + self.address_line_2 unless self.address_line_2.blank?
      #output += ', ' + self.town.best_name_value unless self.town.blank?
      output += ', ' + self.town unless self.town.blank?
      output += ', ' + self.city unless self.city.blank?
      #output += ', ' + self.region.best_name_value unless self.region.blank?
      output += ', ' + self.region unless self.region.blank?
      output += ', ' + self.country.best_name unless self.country.blank?
      output
    end

    # describes how to retrieve the address from the model, if you use
    # directly a db column, you can dry your code, see wiki
    def gmaps4rails_address
      output = self.building.blank? ? '' : self.building
      output += self.building.blank? ? self.address_line_1 : ', ' + self.address_line_1
      output += ', ' + self.address_line_2 unless self.address_line_2.blank?
      #output += ', ' + self.town.best_name_value('en') unless self.town.blank?
      output += ', ' + self.town unless self.town.blank?
      output += ', ' + self.city unless self.city.blank?
      #output += ', ' + self.region.best_name_value('en') unless self.region.blank?
      output += ', ' + self.region unless self.region.blank?
      output += ', ' + self.postal_code unless self.postal_code.blank?
      output += ', ' + self.country.best_name unless self.country.blank?
      output
    end
  end
end

==> core_models-0.0.2.gem: app/models/core_models/base/address.rb <==
require 'geocoder'

module CoreModels
  class Base::Address < ActiveRecord::Base
    belongs_to :country, :class_name => '::CoreModels::Base::Country'
    belongs_to :owner, :polymorphic => true

    #::Gmaps4rails::ActsAsGmappable::ClassMethods.acts_as_gmappable :validation => false
    #acts_as_gmappable :validation => false unless Rails.env == 'test'
    geocoded_by         :gmaps4rails_address                # can also be an IP address
    reverse_geocoded_by :latitude, :longitude
    after_validation    :geocode unless (Rails.env == 'test')  # auto-fetch coordinates

    attr_accessible :room, :building, :address_line_1, :address_line_2, :postal_code, :town, :city, :region
    attr_accessible :email_1, :email_2, :email_3, :url_1, :url_2, :url_3
    attr_accessible :telephone_number_1, :telephone_number_2, :fax_number_1, :fax_number_2

    attr_accessible :latitude, :longitude

    #if ::Rails.env.test?
    attr_accessible :country, :country_id
    attr_accessible :owner, :owner_id
    #end

    attr_accessible :world_coordinates

    validates :address_line_1, :presence => true
    #validates :postal_code, :presence => true
    #validates :town, :presence => true
    #validates :region, :presence => true
    validates :country, :presence => true

    #----------------------------------------------------------------------------

    def to_s
      summary
    end

    def summary
      summary_en
    end

    def summary_en
      output = self.building.blank? ? '' : self.building
      output += self.building.blank? ? self.address_line_1 : ', ' + self.address_line_1
      output += ', ' + self.address_line_2 unless self.address_line_2.blank?
      #output += ', ' + self.town.best_name_value unless self.town.blank?
      output += ', ' + self.town unless self.town.blank?
      output += ', ' + self.city unless self.city.blank?
      #output += ', ' + self.region.best_name_value unless self.region.blank?
      output += ', ' + self.region unless self.region.blank?
      output += ', ' + self.country.best_name unless self.country.blank?
      output
    end

    # describes how to retrieve the address from the model, if you use
    # directly a db column, you can dry your code, see wiki
    def gmaps4rails_address
      output = self.building.blank? ? '' : self.building
      output += self.building.blank? ? self.address_line_1 : ', ' + self.address_line_1
      output += ', ' + self.address_line_2 unless self.address_line_2.blank?
      #output += ', ' + self.town.best_name_value('en') unless self.town.blank?
      output += ', ' + self.town unless self.town.blank?
      output += ', ' + self.city unless self.city.blank?
      #output += ', ' + self.region.best_name_value('en') unless self.region.blank?
      output += ', ' + self.region unless self.region.blank?
      output += ', ' + self.postal_code unless self.postal_code.blank?
      output += ', ' + self.country.best_name unless self.country.blank?
      output
    end
  end
end
